@@ -11,7 +11,10 @@ no_default2 = loads(dumps('__no__default__'))
 
 def test_fold():
     assert fold(add, range(10), 0) == reduce(add, range(10), 0)
-    assert fold(add, range(10), 0, map=Pool().map) == reduce(add, range(10), 0)
+
+    with Pool() as pool:
+        assert fold(add, range(10), 0, map=pool.map) == reduce(add, range(10), 0)
+
     assert fold(add, range(10), 0, chunksize=2) == reduce(add, range(10), 0)
     assert fold(add, range(10)) == fold(add, range(10), 0)
 
